@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2002-2015 Horde LLC
+ * @copyright 2002-2016 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -18,7 +18,7 @@
  * @author    Jan Schneider <jan@horde.org>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2002-2015 Horde LLC
+ * @copyright 2002-2016 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -106,7 +106,8 @@ class Ingo_Basic_Spam extends Ingo_Basic_Base
         $this->header = _("Spam Filtering");
 
         Horde::startBuffer();
-        $form->renderActive($renderer, $this->vars, self::url(), 'post');
+        Horde_Util::pformInput();
+        $form->renderActive($renderer, $this->vars, self::url(array('append_session' => -1)), 'post');
         $this->output = Horde::endBuffer();
     }
 
@@ -114,7 +115,10 @@ class Ingo_Basic_Spam extends Ingo_Basic_Base
      */
     static public function url(array $opts = array())
     {
-        return Horde::url('basic.php')->add('page', 'spam');
+        if (empty($opts['append_session'])) {
+            $opts['append_session'] = 0;
+        }
+        return Horde::url('basic.php', true, array('append_session' => $opts['append_session']))->add('page', 'spam');
     }
 
 }
