@@ -103,3 +103,7 @@ $enable_img = $this->hordeImage('enable.png');
  </p>
 </form>
 <?php endif; ?>
+
+<div id="filtersSave" style="display:none">
+ <span><?php echo _("Saving...") ?></span>
+</div>
